@@ -529,6 +529,8 @@ module.exports = {
 	"8.5.1": "80.0.3987.165",
 	"8.5.2": "80.0.3987.165",
 	"8.5.3": "80.0.3987.163",
+	"8.5.4": "80.0.3987.163",
+	"8.5.5": "80.0.3987.163",
 	"9.0.0-beta.1": "82.0.4048.0",
 	"9.0.0-beta.2": "82.0.4048.0",
 	"9.0.0-beta.3": "82.0.4048.0",
@@ -603,6 +605,9 @@ module.exports = {
 	"9.3.1": "83.0.4103.122",
 	"9.3.2": "83.0.4103.122",
 	"9.3.3": "83.0.4103.122",
+	"9.3.4": "83.0.4103.122",
+	"9.3.5": "83.0.4103.122",
+	"9.4.0": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
@@ -690,6 +695,9 @@ module.exports = {
 	"10.1.3": "85.0.4183.121",
 	"10.1.4": "85.0.4183.121",
 	"10.1.5": "85.0.4183.121",
+	"10.1.6": "85.0.4183.121",
+	"10.1.7": "85.0.4183.121",
+	"10.2.0": "85.0.4183.121",
 	"11.0.0-beta.1": "86.0.4234.0",
 	"11.0.0-beta.3": "86.0.4234.0",
 	"11.0.0-beta.4": "86.0.4234.0",
@@ -704,6 +712,10 @@ module.exports = {
 	"11.0.0-beta.16": "87.0.4280.27",
 	"11.0.0-beta.17": "87.0.4280.27",
 	"11.0.0-beta.18": "87.0.4280.27",
+	"11.0.0-beta.19": "87.0.4280.27",
+	"11.0.0-beta.20": "87.0.4280.40",
+	"11.0.0-beta.22": "87.0.4280.47",
+	"11.0.0-beta.23": "87.0.4280.47",
 	"11.0.0-nightly.20200525": "84.0.4129.0",
 	"11.0.0-nightly.20200526": "84.0.4129.0",
 	"11.0.0-nightly.20200529": "85.0.4156.0",
@@ -743,6 +755,22 @@ module.exports = {
 	"11.0.0-nightly.20200824": "86.0.4234.0",
 	"11.0.0-nightly.20200825": "86.0.4234.0",
 	"11.0.0-nightly.20200826": "86.0.4234.0",
+	"11.0.0": "87.0.4280.60",
+	"11.0.1": "87.0.4280.60",
+	"11.0.2": "87.0.4280.67",
+	"11.0.3": "87.0.4280.67",
+	"11.0.4": "87.0.4280.67",
+	"11.0.5": "87.0.4280.88",
+	"11.1.0": "87.0.4280.88",
+	"12.0.0-beta.1": "89.0.4328.0",
+	"12.0.0-beta.3": "89.0.4328.0",
+	"12.0.0-beta.4": "89.0.4328.0",
+	"12.0.0-beta.5": "89.0.4328.0",
+	"12.0.0-beta.6": "89.0.4328.0",
+	"12.0.0-beta.7": "89.0.4328.0",
+	"12.0.0-beta.8": "89.0.4328.0",
+	"12.0.0-beta.9": "89.0.4328.0",
+	"12.0.0-beta.10": "89.0.4328.0",
 	"12.0.0-nightly.20200827": "86.0.4234.0",
 	"12.0.0-nightly.20200831": "86.0.4234.0",
 	"12.0.0-nightly.20200902": "86.0.4234.0",
@@ -756,5 +784,29 @@ module.exports = {
 	"12.0.0-nightly.20201015": "87.0.4268.0",
 	"12.0.0-nightly.20201023": "88.0.4292.0",
 	"12.0.0-nightly.20201026": "88.0.4292.0",
-	"12.0.0-nightly.20201030": "88.0.4306.0"
+	"12.0.0-nightly.20201030": "88.0.4306.0",
+	"12.0.0-nightly.20201102": "88.0.4306.0",
+	"12.0.0-nightly.20201103": "88.0.4306.0",
+	"12.0.0-nightly.20201104": "88.0.4306.0",
+	"12.0.0-nightly.20201105": "88.0.4306.0",
+	"12.0.0-nightly.20201106": "88.0.4306.0",
+	"12.0.0-nightly.20201111": "88.0.4306.0",
+	"12.0.0-nightly.20201112": "88.0.4306.0",
+	"12.0.0-nightly.20201116": "88.0.4324.0",
+	"13.0.0-nightly.20201119": "89.0.4328.0",
+	"13.0.0-nightly.20201123": "89.0.4328.0",
+	"13.0.0-nightly.20201124": "89.0.4328.0",
+	"13.0.0-nightly.20201126": "89.0.4328.0",
+	"13.0.0-nightly.20201127": "89.0.4328.0",
+	"13.0.0-nightly.20201130": "89.0.4328.0",
+	"13.0.0-nightly.20201201": "89.0.4328.0",
+	"13.0.0-nightly.20201202": "89.0.4328.0",
+	"13.0.0-nightly.20201203": "89.0.4328.0",
+	"13.0.0-nightly.20201204": "89.0.4328.0",
+	"13.0.0-nightly.20201207": "89.0.4328.0",
+	"13.0.0-nightly.20201208": "89.0.4328.0",
+	"13.0.0-nightly.20201209": "89.0.4328.0",
+	"13.0.0-nightly.20201210": "89.0.4328.0",
+	"13.0.0-nightly.20201211": "89.0.4328.0",
+	"13.0.0-nightly.20201214": "89.0.4328.0"
 };
\ No newline at end of file
